==> apache-servicecomb-java-chassis-distribution-1.3.11-src.zip: apache-servicecomb-java-chassis-distribution-1.3.11-src/foundations/foundation-metrics/src/main/java/org/apache/servicecomb/foundation/metrics/publish/spectator/MeasurementGroupConfig.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.servicecomb.foundation.metrics.publish.spectator;

import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

public class MeasurementGroupConfig {
  // key is measurement id name
  private Map<String, List<TagFinder>> groups = new HashMap<>();

  public MeasurementGroupConfig() {
  }

  public MeasurementGroupConfig(String idName, Object... tagNameOrFinders) {
    addGroup(idName, tagNameOrFinders);
  }

  public void addGroup(String idName, Object... tagNameOrFinders) {
    groups.put(idName,
        Arrays
            .asList(tagNameOrFinders)
            .stream()
            .map(r -> TagFinder.build(r))
            .collect(Collectors.toList()));
  }

  public List<TagFinder> findTagFinders(String idName) {
    return groups.get(idName);
  }
}

==> apache-servicecomb-java-chassis-distribution-2.8.16-src.zip: apache-servicecomb-java-chassis-distribution-2.8.16-src/foundations/foundation-metrics/src/main/java/org/apache/servicecomb/foundation/metrics/publish/spectator/MeasurementGroupConfig.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.servicecomb.foundation.metrics.publish.spectator;

import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

public class MeasurementGroupConfig {
  // key is measurement id name
  private final Map<String, List<TagFinder>> groups = new HashMap<>();

  public MeasurementGroupConfig() {
  }

  public MeasurementGroupConfig(String idName, Object... tagNameOrFinders) {
    addGroup(idName, tagNameOrFinders);
  }

  public void addGroup(String idName, Object... tagNameOrFinders) {
    groups.put(idName,
        Arrays
            .asList(tagNameOrFinders)
            .stream()
            .map(TagFinder::build)
            .collect(Collectors.toList()));
  }

  public List<TagFinder> findTagFinders(String idName) {
    return groups.get(idName);
  }
}
